#
# spec file for package python-userpath
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-userpath
Version:        1.9.0
Release:        1.1
Summary:        Tool for adding locations to the user PATH
License:        MIT
URL:            https://github.com/ofek/userpath
Source:         https://files.pythonhosted.org/packages/source/u/userpath/userpath-%{version}.tar.gz
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-click
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module click}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
Cross-platform tool for adding locations to the user PATH,
with no elevated privileges required.

%prep
%autosetup -p1 -n userpath-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/userpath
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LC_ALL=C.UTF-8
%pytest

%post
%python_install_alternative userpath

%postun
%python_uninstall_alternative userpath

%files %{python_files}
%doc README.md
%license LICENSE.txt
%python_alternative %{_bindir}/userpath
%{python_sitelib}/userpath
%{python_sitelib}/userpath-%{version}*-info

%changelog
* Thu Aug 10 2023 Daniel Garcia <daniel.garcia@suse.com>
- add sle15_python_module_pythons (jsc#PED-68, jsc#PED-5573)
- update to 1.9.0
  * Ignore the current directory for path detection on Windows
  * On non-Windows systems only modify login shells
- v1.8.0
  * Broadcast WM_SETTINGCHANGE on Windows
  * Drop Python 2.7 & 3.6
* Mon Mar 14 2022 PragmaticLinux <info@pragmaticlinux.com>
- update to 1.7.0
  * Fix path normalization to be aware of case-insensitive
    platforms and symlinks.
  * Use locale's encoding when handling output from subprocesses
  * Modify bash start-up files based on their existence
  * Remove distro dependency
  * Fix fallback mechanism for detecting the name of the parent
    process
* Thu Jul 23 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 1.4.1
  * Prevent adding paths multiple times on macOS/Linux
  * Send CLI errors to stderr instead of stdout
* Mon May 18 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Wed Oct 23 2019 Tomáš Chvátal <tchvatal@suse.com>
- Fix license string
* Mon Oct 21 2019 John Vandenberg <jayvdb@gmail.com>
- Update to v1.3.0
* Wed Sep 11 2019 John Vandenberg <jayvdb@gmail.com>
- Update spec for userpath v1.2.0
* Thu Aug  2 2018 aboe76@gmail.com
- python-addduserpath initial packaging
